@@ -1,4 +1,4 @@
-import BaseModel # seq2seq module
+from CustomModel import * # seq2seq module
 from Utils import * # other functions
 
 def model_only(sentence):
